
#ifndef LUBISHEV_SCENE_EVENT_H
#define LUBISHEV_SCENE_EVENT_H

#include <lubishev/TextDocument.h>
#include <lubishev/Types.h>

#include <QPainter>
#include <QRectF>

namespace lubishev {

class Scene;

class SceneEvent {
    public:
        SceneEvent(Scene *scn, Event *e);
        ~SceneEvent();

        enum PART {
            NONE = 0,
            EVENT,
            HANDLE_TOP,
            HANDLE_BOTTOM
        };

        PART contains(const QPointF &pos) const;
        // Result of the last call of contains(..).
        PART containsResult() const;
        static void dehoverMouseAbove();
        static void deselectSelected();
        void draw(QPainter *p);
        void drawText(QPainter *p);
        Event* event();
        bool isMouseAbove() const;
        bool isSelected() const;
        static SceneEvent* mouseAbove();
        void refreshRect();
        void refreshText();
        static SceneEvent* selected();
        void setMouseAbove(bool state);
        void setSelected(bool state);
        void setSelectedPartTime(time_t t);

    private:
        Scene* mScene;
        Event* mEvent;
        QRectF mRect;
        QRectF mHandleTop;
        QRectF mHandleBottom;
        bool mDisplayAddons;
        mutable PART mContainsResult;
        TextDocument *mDoc;

        static SceneEvent *mSelected;
        static SceneEvent *mMouseAbove;
};

} // namespace lubishev

#endif // LUBISHEV_SCENE_EVENT_H

